@@ -10,16 +10,17 @@
 #include <fcntl.h>
 #include <sys/ioctl.h>
 #include <linux/kd.h>
+#include "getfd.h"
+#include "nls.h"
+#include "version.h"
 
-extern int getfd();
-
-void
+static void
 usage(char *s) {
     fprintf(stderr, "setkeycode: %s\n", s);
-    fprintf(stderr, "\
-usage: setkeycode scancode keycode ...\n\
- (where scancode is either xx or e0xx, given in hexadecimal,
-  and keycode is given in decimal)\n");
+    fprintf(stderr, _(
+"usage: setkeycode scancode keycode ...\n"
+" (where scancode is either xx or e0xx, given in hexadecimal,\n"
+"  and keycode is given in decimal)\n"));
     exit(1);
 }
 
@@ -29,24 +30,33 @@ main(int argc, char **argv) {
     int fd, sc;
     struct kbkeycode a;
 
+    set_progname(argv[0]);
+
+    setlocale(LC_ALL, "");
+    bindtextdomain(PACKAGE, LOCALEDIR);
+    textdomain(PACKAGE);
+
+    if (argc == 2 && !strcmp(argv[1], "-V"))
+      print_version_and_exit();
+
     if (argc % 2 != 1)
-      usage("even number of arguments expected");
-    fd = getfd();
+      usage(_("even number of arguments expected"));
+    fd = getfd(NULL);
 
     while (argc > 2) {
 	a.keycode = atoi(argv[2]);
 	a.scancode = sc = strtol(argv[1], &ep, 16);
 	if (*ep)
-	  usage("error reading scancode");
+	  usage(_("error reading scancode"));
 	if (a.scancode > 127) {
 	    a.scancode -= 0xe000;
 	    a.scancode += 128;
 	}
 	if (a.scancode > 255 || a.keycode > 127)
-	  usage("code outside bounds");
+	  usage(_("code outside bounds"));
 	if (ioctl(fd,KDSETKEYCODE,&a)) {
 	    perror("KDSETKEYCODE");
-	    fprintf(stderr, "failed to set scancode %x to keycode %d\n",
+	    fprintf(stderr, _("failed to set scancode %x to keycode %d\n"),
 		    sc, a.keycode);
 	    exit(1);
 	}
